@@ -332,7 +332,7 @@ class Objeto():
     def _cair(self):
         clock_padrao = 100
         while rodar_threading:
-            if( not self.cai ):
+            if( not self.cai or pausado ):
                 pygame.time.Clock().tick( clock_padrao )
                 continue
             elif( self._velocidade_de_queda > 0 ):
